% set_mean computes the set mean of a dataset S approximated on the
% elements of a subset X of data space, based solely on distances 
% d(x_i, s_j) between elements of X and S.
%
% Defined in the paper 'Tree-space statistics and approximations for 
% large-scale analysis of anatomical trees (Aasa Feragen, Megan Owen, Jens 
% Petersen, Mathilde M. W. Wille, Laura H. Thomsen, Asger Dirksen, and 
% Marleen de Bruijne), Information Processing in Medical Imaging 2013, 
% Lecture Notes in Computer Science 7917'.
%
% mean_index = set_mean(D)
%
% Assume given 
%  - a dataset X with m elements in data space Y, such that X spans Y 
%    as well as possible 
%  - a set S with n elements, usually a subset of X, of which we wish 
%    to compute the set mean, that is the element x from X that 
%    minimizes sum_i d^2(x,s_i)
%  - an (m x n) distancematrix D, where where D(i,j) is the distance 
%    from x_i in X to s_j in S
%
%
% Input variables:
%   D
%
% Output variables:
%  mean_index (the index i of the set mean x_i as an element of X)
%
% Copyright (C) 2013 Aasa Feragen
% 
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
%
% Author: Aasa Feragen <aasa at diku dot dk>
% 
% 2013-06-16 Aasa Feragen <aasa at diku dot dk>
% * Initial revision


function mean_index = set_mean(D)
    sum_squared_distances = sum(D.^2, 2);
    
    mean_index = find(sum_squared_distances == min(sum_squared_distances));
end