function treestats_demo
    % This is a demo of the matlab interfaces to TreeStats
    
    %----------------------------------------------------------------------
    %
    % Using set_mean.m:
    
    D = abs(randn(100, 50));   
    % D is a random distance matrix containing distances from the dataset S 
    % (50 elements) to the set X (100 elements) approximating data-space
    
    mean_index = set_mean(D);
    % mean_index is the index of the element in X which minimizes the
    % Fréchet mean cost function
    
    %----------------------------------------------------------------------
    %
    % Using hypothesis_test_setmeans.m
    
    D = randn(1000);
    D_set = abs(D*D');
    S_indices = randsample(1000, 200);
    classification_vector = zeros(1, 200);
    classification_vector(1:100) = 1;
    
    % Randomly sampled distance matrix D_set for m = 1000 element dataset
    % Randomly sampled indices of n = 200 element subset S
    % Synthetic classification vector
    
    [h, p] = hypothesis_test_setmeans(D_set, S_indices, classification_vector, 'T', 1000);    
    
    %----------------------------------------------------------------------
    %
    % Using hypothesis_test_setmeans.m
    %
    load('classification_vector');
    % Load synthetic classification vector
    
    [h, p] = hypothesis_test_sturmmeans('airways_dataset.txt', classification_vector, 'S1', 2);
    
    %----------------------------------------------------------------------
    %
    % Using pca.m
    
    [start_index, end_index] = pca(10, 0.005, 'airways_dataset.txt');
    
    %----------------------------------------------------------------------
    %
    % Using lda.m
    
    load('training_test');
    % Load training/test set assignment vector
    
    [start_tree, end_tree, classification_accuracy] = lda(10, 0.005, 'airways_dataset.txt', classification_vector, training_test);

end